prhvrules ObjectPromote a data frame to a prHvrules object, containing plot-ready
hvrules for a table. This is an internal function not intended to be
called by package users.
as.prHvrules(x)An object of S3 class prHvrules and data.frame. See
function prHvrules for a full description of the class.
An object inheriting from data.frame. Each row represents one
horizontal or vertical rule (hvrule) to apppear in a table. See
dfSpecs for the required columns and types, and prHvrules
for a description of these columns.
Normally plot-ready hvrules are created from a tblBlocks object via
function prHvrules. This function allows them to be created or
edited directly in a data frame, without necessarily using a predefined
style.
Columns arow1, arow2, acol1 and acol2 refer to
row and column numbers in the augmented row-column grid of the table; see
adim for more information.
For an hrule (horizontal rule), arow1 and arow2 should be
equal to each other and to a half-integer; the hrule will be inserted
between table row numbers that bracket the value. (For example,
arow1 = arow2 = 3.5 means the hrule will be inserted between rows 3
and 4.) acol1 and acol2 should be integers that indicate
the first and last columns to be spanned by the hrule.
For a vrule (vertical rule) the specification is similar, but with the
roles of arow* and acol* reversed.
If column enabled was not present in x it will be added,
with value FALSE for all hvrules.
If x is already a prHvrules object, this function does some
validity checks. If x is NULL, a valid but empty prHvrules
object is returned.
prHvrules, tblBlocks