Return a data frame with specifications for graphical properties associated with an element type. This is an internal function, not intended to be called by package users.
grSpecs(type)A data frame with one row per graphical property. Columns are name
(the name of the property); mode (mode/type of values taken by the
property); NA_ok (logical, TRUE if NA is a valid value for the
property); and scalable (logical, TRUE if the property is to be
treated as scalable).
Property names are used as the row names of the data frame.
Element type, one of entry, block, hvrule.
Graphical properties are documented in ?elements.
df_from_spec, which uses the output from this function to
create a template data frame for graphical properties.